"""读取 AKSHARE_ONE_PROXY 环境变量，自动设置 http_proxy / https_proxy。"""

import os

_proxy = os.getenv("AKSHARE_ONE_PROXY")
if _proxy:
    os.environ.setdefault("http_proxy", _proxy)
    os.environ.setdefault("https_proxy", _proxy)
