"""Options derived indicator schema constants.

期权衍生指标 DataFrame 列名常量。
"""

from typing import Final

COL_DELTA: Final[str] = "delta"
COL_GAMMA: Final[str] = "gamma"
COL_THETA: Final[str] = "theta"
COL_VEGA: Final[str] = "vega"
COL_RHO: Final[str] = "rho"
COL_IV: Final[str] = "iv"

COL_THEORETICAL_VALUE: Final[str] = "theoretical_value"
COL_TIME_VALUE: Final[str] = "time_value"
COL_INTRINSIC_VALUE: Final[str] = "intrinsic_value"

COL_LEVERAGE: Final[str] = "leverage"
COL_EFFECTIVE_LEVERAGE: Final[str] = "effective_leverage"

OPTIONS_GREEKS_COLUMNS: Final[tuple[str, ...]] = (
    COL_DELTA,
    COL_GAMMA,
    COL_THETA,
    COL_VEGA,
    COL_RHO,
    COL_IV,
    COL_THEORETICAL_VALUE,
)

OPTIONS_VALUE_ANALYSIS_COLUMNS: Final[tuple[str, ...]] = (
    COL_TIME_VALUE,
    COL_INTRINSIC_VALUE,
    COL_IV,
    COL_THEORETICAL_VALUE,
)

OPTIONS_LEVERAGE_COLUMNS: Final[tuple[str, ...]] = (
    COL_LEVERAGE,
    COL_EFFECTIVE_LEVERAGE,
)
